fig_figure: Insert a figure from a figr table.

Description Usage Arguments Value

Description

This function is given a figr table and an index or short filename and will then insert the corresponding figure into the html document together with a label to permit linking.

Usage

1
2
fig_figure(figr_tbl, index, width = 70, add_titles = FALSE,
  pagebreak = TRUE)

Arguments

figr_tbl

A figr table

index

Either an integer index or short filename

width

Figure width as % of page

add_titles

If TRUE adds filenames

pagebreak

If TRUE inserts pagebreak before figure

Value

Returns nothing, sideeffect is inserting figure


ianhandel/figr documentation built on May 30, 2019, 8:24 a.m.