fig_label: Create a named label - defaults to 'home'

Description Usage Arguments Value Examples

Description

This function creates an html label tag manually, defaulting to 'home'. Likely to be used to give a return location from figures,

Usage

1
fig_label(label = "home")

Arguments

label

The label tag

Value

Returns nothing, sideeffect is printing label

Examples

1
2
3
4
## Not run: 
fig_label()

## End(Not run)

ianhandel/figr documentation built on May 30, 2019, 8:24 a.m.