fig_link: Create a named link - defaults to 'home'

Description Usage Arguments Value Examples

Description

This function creates a link tag manually, defaulting to 'home'. Likely to be used to give a return link from figures,

Usage

1
fig_link(label = "home", text = "back", newline = TRUE)

Arguments

label

The link tag

text

The text to display (deafults to 'back')

newline

If TRUE inserts newline before link

Value

Returns nothing, sideeffect is printing link

Examples

1
2
3
4
## Not run: 
fig_link()

## End(Not run)

ianhandel/figr documentation built on May 30, 2019, 8:24 a.m.