Sets a global option for the target journal. This prevents you from needing
to specify the journal argument in every call to publish_fig().
Sets a global option for the target journal. This prevents you from needing
to specify the journal argument in every call to publish_fig().