Description Usage Arguments Value Examples
This fucntion is given either a list of filenames or pointed to a directory. It will creat a table with formatted link and label text for inclusion in a RMarkdown document. Filenames are filtered to only include those with specified file extensions.
1 2 | fig_create(filenames = NULL, dir = NULL, desc = FALSE,
extensions = ".(tif|png)$")
|
filenames |
A character vector of filenames |
dir |
A path to a directory of image files |
desc |
If TRUE table is sorted on descending filename or sort key |
extensions |
Regex to filter file extensions |
Returns a table with column of text links and text labels.
1 2 3 4 | ## Not run:
fig_create(dir = ".", desc = TRUE)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.