Description Usage Arguments Value
This function is given a figr table and an index or short filename and will then insert the corresponding figure into the html document together with a label to permit linking.
1 2 | fig_figure(figr_tbl, index, width = 70, add_titles = FALSE,
pagebreak = TRUE)
|
figr_tbl |
A figr table |
index |
Either an integer index or short filename |
width |
Figure width as % of page |
add_titles |
If TRUE adds filenames |
pagebreak |
If TRUE inserts pagebreak before figure |
Returns nothing, sideeffect is inserting figure
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.