Description Usage Arguments Value Examples
This function creates an html label tag manually, defaulting to 'home'. Likely to be used to give a return location from figures,
1 | fig_label(label = "home")
|
label |
The label tag |
Returns nothing, sideeffect is printing label
1 2 3 4 | ## Not run:
fig_label()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.