Description Usage Arguments Value Examples
This function creates a link tag manually, defaulting to 'home'. Likely to be used to give a return link from figures,
1 |
label |
The link tag |
text |
The text to display (deafults to 'back') |
newline |
If TRUE inserts newline before link |
Returns nothing, sideeffect is printing link
1 2 3 4 | ## Not run:
fig_link()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.